@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright 2001-2024 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** Licensed under the Apache License, Version 2.0 (the "License");
 ** you may not use this file except in compliance with the License.
@@ -20,8 +20,8 @@ package params
 import (
 	"testing"
 
-	"git.zabbix.com/ap/plugin-support/metric"
 	"github.com/google/go-cmp/cmp"
+	"golang.zabbix.com/sdk/metric"
 )
 
 func TestJoin(t *testing.T) {
